"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const glob_1 = tslib_1.__importDefault(require("glob"));
const path_1 = tslib_1.__importDefault(require("path"));
const pGlop = (pattern, options = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    return new Promise((resolve, reject) => {
        glob_1.default(pattern, options, (err, files) => {
            if (err) {
                reject(err);
                return;
            }
            resolve(files);
        });
    });
});
const exclude = (excludes, packagePath) => Boolean(excludes.indexOf(packagePath) < 0);
const include = (includes, packagePath) => Boolean(includes.indexOf(packagePath) >= 0);
function getJsonFile(pathName) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return JSON.parse(yield fs_extra_1.default.readFile(pathName, 'utf8'));
    });
}
// Returns all packages and it's path's in you project
function getLernaPackages(projectRootDir, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const lernaData = yield getJsonFile(path_1.default.join(projectRootDir, 'lerna.json'));
        const rootPkgData = yield getJsonFile(path_1.default.join(projectRootDir, 'package.json'));
        const packagesGlobs = lernaData.packages || rootPkgData.workspaces;
        if (!packagesGlobs) {
            return [];
        }
        const packagesRaw = yield Promise.all(packagesGlobs.map((packageGlob) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            return pGlop(packageGlob, {
                cwd: projectRootDir,
            });
        })));
        const isValidPackagePath = (packagePath) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            try {
                return (yield fs_extra_1.default.stat(path_1.default.join(projectRootDir, packagePath, 'package.json'))).isFile();
            }
            catch (err) {
                return false;
            }
        });
        const packages = packagesRaw.reduce((a, b) => [...a, ...b]);
        if (options && options.include) {
            return packages.filter(isValidPackagePath).filter(include.bind(null, options.include));
        }
        if (options && options.exclude) {
            return packages.filter(isValidPackagePath).filter(exclude.bind(null, options.exclude));
        }
        return packages.filter(isValidPackagePath);
    });
}
exports.getLernaPackages = getLernaPackages;
//# sourceMappingURL=get-lerna-packages.js.map